@@ -125,6 +125,32 @@ describe('clone()', () => {
         expect(a).to.equal(b);
     });
 
+    it('clones holey arrays', () => {
+
+        const a = new Array(3);
+        a[1] = 'one';
+
+        const b = Hoek.clone(a);
+
+        expect(a).to.equal(b);
+    });
+
+    it('clones symbol properties', () => {
+
+        const sym1 = Symbol(1);
+        const sym2 = Symbol(2);
+        const a = { [sym1]: 1 };
+        Object.defineProperty(a, sym2, { value: 2 });
+
+        const b = Hoek.clone(a, { symbols: true });
+
+        expect(a).to.equal(b);
+        expect(b[sym1]).to.be.equal(1);
+        expect(b[sym2]).to.be.equal(2);
+
+        expect(Hoek.deepEqual(a, b, { symbols: true })).to.be.true();
+    });
+
     it('performs actual copy for shallow keys (no pass by reference)', () => {
 
         const x = Hoek.clone(nestedObj);
@@ -361,6 +387,26 @@ describe('clone()', () => {
         Object.getOwnPropertyDescriptor = oldGetOwnPropertyDescriptor;
         expect(copy).to.equal(obj);
     });
+
+    it('clones own property when class property is not writable', () => {
+
+        const Cl = class {
+
+            get x() {
+
+                return 'hi';
+            }
+        };
+
+        const obj = new Cl();
+
+        Object.defineProperty(obj, 'x', {
+            value: 0, writable: true
+        });
+
+        const copy = Hoek.clone(obj);
+        expect(copy).to.equal(obj);
+    });
 });
 
 describe('merge()', () => {
@@ -423,6 +469,31 @@ describe('merge()', () => {
         expect(a.x[0]).to.not.exist();
     });
 
+    it('merges from null prototype objects', () => {
+
+        const a = {};
+
+        const b = Object.create(null);
+        b.x = true;
+
+        Hoek.merge(a, b);
+        expect(a.x).to.be.true();
+    });
+
+    it('skips non-enumerable properties', () => {
+
+        const a = { x: 0 };
+
+        const b = {};
+        Object.defineProperty(b, 'x', {
+            enumerable: false,
+            value: 1
+        });
+
+        Hoek.merge(a, b);
+        expect(a.x).to.equal(0);
+    });
+
     it('does not throw if source is null', () => {
 
         const a = {};
@@ -554,6 +625,23 @@ describe('merge()', () => {
         expect(a.x.toString()).to.equal('abc');
     });
 
+    it('overrides RegExp', () => {
+
+        const a = { x: /test/ };
+
+        Hoek.merge({ x: {} }, a);
+        expect(a.x).to.equal(/test/);
+    });
+
+    it('overrides Symbol properties', () => {
+
+        const sym = Symbol();
+        const a = { [sym]: 1 };
+
+        Hoek.merge({ [sym]: {} }, a);
+        expect(a[sym]).to.equal(1);
+    });
+
     it('skips __proto__', () => {
 
         const a = '{ "ok": "value", "__proto__": { "test": "value" } }';
@@ -662,14 +750,16 @@ describe('cloneWithShallow()', () => {
             },
             c: {
                 d: 6
-            }
+            },
+            e() { }
         };
 
-        const copy = Hoek.cloneWithShallow(source, ['c']);
+        const copy = Hoek.cloneWithShallow(source, ['c', 'e']);
         expect(copy).to.equal(source);
         expect(copy).to.not.shallow.equal(source);
         expect(copy.a).to.not.shallow.equal(source.a);
-        expect(copy.b).to.equal(source.b);
+        expect(copy.c).to.shallow.equal(source.c);
+        expect(copy.e).to.shallow.equal(source.e);
     });
 
     it('returns immutable value', () => {
@@ -704,6 +794,25 @@ describe('cloneWithShallow()', () => {
         expect(copy.a).to.not.shallow.equal(source.a);
         expect(copy.b).to.equal(source.b);
     });
+
+    it('supports symbols', () => {
+
+        const sym = Symbol();
+        const source = {
+            a: {
+                b: 5
+            },
+            [sym]: {
+                d: 6
+            }
+        };
+
+        const copy = Hoek.cloneWithShallow(source, [[sym]], { symbols: true });
+        expect(copy).to.equal(source);
+        expect(copy).to.not.shallow.equal(source);
+        expect(copy.a).to.not.shallow.equal(source.a);
+        expect(copy[sym]).to.equal(source[sym]);
+    });
 });
 
 describe('applyToDefaultsWithShallow()', () => {
@@ -1020,6 +1129,31 @@ describe('deepEqual()', () => {
         compare();
     });
 
+    it('compares symbol object properties', () => {
+
+        const sym = Symbol();
+
+        const ne = {};
+        Object.defineProperty(ne, sym, { value: true });
+
+        expect(Hoek.deepEqual({ [sym]: { c: true } }, { [sym]: { c: true } }, { symbols: true })).to.be.true();
+        expect(Hoek.deepEqual({ [sym]: { c: true } }, { [sym]: { c: false } }, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual({ [sym]: { c: true } }, { [sym]: true }, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual({ [sym]: undefined }, { [sym]: undefined }, { symbols: true })).to.be.true();
+        expect(Hoek.deepEqual({ [sym]: undefined }, {}, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual({}, { [sym]: undefined }, { symbols: true })).to.be.false();
+
+        expect(Hoek.deepEqual({}, ne, { symbols: true })).to.be.true();
+        expect(Hoek.deepEqual(ne, {}, { symbols: true })).to.be.true();
+        expect(Hoek.deepEqual({ [sym]: true }, ne, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual(ne, { [sym]: true }, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual(ne, { [Symbol()]: undefined }, { symbols: true })).to.be.false();
+
+        expect(Hoek.deepEqual({ [sym]: true }, { [sym]: true }, { symbols: true })).to.be.true();
+        expect(Hoek.deepEqual({ [sym]: true }, {}, { symbols: true })).to.be.false();
+        expect(Hoek.deepEqual({ [sym]: true }, {}, { symbols: false })).to.be.true();
+    });
+
     it('compares dates', () => {
 
         expect(Hoek.deepEqual(new Date(2015, 1, 1), new Date('2015/02/01'))).to.be.true();
@@ -1098,6 +1232,7 @@ describe('deepEqual()', () => {
         expect(Hoek.deepEqual(new Map([[1, {}]]), new Map([[1, {}]]))).to.be.true();
         expect(Hoek.deepEqual(new Map([[1, item1]]), new Map([[1, item1]]))).to.be.true();
         expect(Hoek.deepEqual(new Map([[1, item1]]), new Map([[1, item2]]))).to.be.false();
+        expect(Hoek.deepEqual(new Map([[1, undefined]]), new Map([[1, undefined]]))).to.be.true();
         expect(Hoek.deepEqual(new Map([[1, undefined]]), new Map([[2, undefined]]))).to.be.false();
         expect(Hoek.deepEqual(new Map([[1, {}]]), new Map([[1, {}], [2, {}]]))).to.be.false();
         expect(Hoek.deepEqual(new Map([[item1, 1]]), new Map([[item1, 1]]))).to.be.true();
@@ -1237,7 +1372,7 @@ describe('deepEqual()', () => {
 
     it('handles valueOf() that throws', () => {
 
-        const throwing  = class {
+        const throwing = class {
 
             constructor(value) {
 
@@ -1645,6 +1780,18 @@ describe('contain()', () => {
             expect(Hoek.contain(foo, { 'a': 1, 'b': 2, 'c': 3 }, { only: true })).to.be.true();
         }
     });
+
+    it('supports symbols', () => {
+
+        const sym = Symbol();
+
+        expect(Hoek.contain([sym], sym)).to.be.true();
+        expect(Hoek.contain({ [sym]: 1 }, sym, { symbols: true })).to.be.true();
+        expect(Hoek.contain({ [sym]: 1, a: 2 }, { [sym]: 1 }, { symbols: true })).to.be.true();
+
+        expect(Hoek.contain([sym], Symbol())).to.be.false();
+        expect(Hoek.contain({ [sym]: 1 }, Symbol(), { symbols: true })).to.be.false();
+    });
 });
 
 describe('flatten()', () => {
@@ -1659,6 +1806,7 @@ describe('flatten()', () => {
 
 describe('reach()', () => {
 
+    const sym = Symbol();
     const obj = {
         a: {
             b: {
@@ -1670,6 +1818,10 @@ describe('reach()', () => {
             },
             g: {
                 h: 3
+            },
+            '-2': true,
+            [sym]: {
+                v: true
             }
         },
         i: function () { },
@@ -1684,18 +1836,26 @@ describe('reach()', () => {
         expect(Hoek.reach(obj, null)).to.equal(obj);
         expect(Hoek.reach(obj, false)).to.equal(obj);
         expect(Hoek.reach(obj)).to.equal(obj);
+        expect(Hoek.reach(obj, [])).to.equal(obj);
     });
 
-    it('returns first value of array', () => {
+    it('returns values of array', () => {
 
         expect(Hoek.reach(obj, 'k.0')).to.equal(4);
+        expect(Hoek.reach(obj, 'k.1')).to.equal(8);
     });
 
     it('returns last value of array using negative index', () => {
 
+        expect(Hoek.reach(obj, 'k.-1')).to.equal(1);
         expect(Hoek.reach(obj, 'k.-2')).to.equal(9);
     });
 
+    it('returns object property with negative index for non-array', () => {
+
+        expect(Hoek.reach(obj, 'a.-2')).to.be.equal(true);
+    });
+
     it('returns a valid member', () => {
 
         expect(Hoek.reach(obj, 'a.b.c.d')).to.equal(1);
@@ -1733,6 +1893,9 @@ describe('reach()', () => {
     it('returns undefined on invalid member', () => {
 
         expect(Hoek.reach(obj, 'a.b.c.d-.x')).to.equal(undefined);
+        expect(Hoek.reach(obj, 'k.x')).to.equal(undefined);
+        expect(Hoek.reach(obj, 'k.1000')).to.equal(undefined);
+        expect(Hoek.reach(obj, 'k/0.5', '/')).to.equal(undefined);
     });
 
     it('returns function member', () => {
@@ -1772,6 +1935,21 @@ describe('reach()', () => {
 
         expect(Hoek.reach(obj, 'q', { default: '' })).to.equal('');
     });
+
+    it('allows array-based lookup', () => {
+
+        expect(Hoek.reach(obj, ['a', 'b', 'c', 'd'])).to.equal(1);
+        expect(Hoek.reach(obj, ['k', '1'])).to.equal(8);
+        expect(Hoek.reach(obj, ['k', 1])).to.equal(8);
+        expect(Hoek.reach(obj, ['k', '-2'])).to.equal(9);
+        expect(Hoek.reach(obj, ['k', -2])).to.equal(9);
+    });
+
+    it('allows array-based lookup with symbols', () => {
+
+        expect(Hoek.reach(obj, ['a', sym, 'v'])).to.equal(true);
+        expect(Hoek.reach(obj, ['a', Symbol(), 'v'])).to.equal(undefined);
+    });
 });
 
 describe('reachTemplate()', () => {
